@@ -111,21 +111,17 @@ def test_predict_image_fromarray(m):
     with pytest.raises(TypeError):
         image = Image.open(image_path)
         prediction = m.predict_image(image = image)
-    
-    with pytest.raises(ValueError):
-        image = np.array(Image.open(image_path))
-        prediction = m.predict_image(image = image)
             
-    image = np.array(Image.open(image_path).convert("RGB")).astype("float32")
+    image = np.array(Image.open(image_path).convert("RGB"))
     prediction = m.predict_image(image = image)    
     assert isinstance(prediction, pd.DataFrame)
     assert set(prediction.columns) == {"xmin","ymin","xmax","ymax","label","score"}
 
 def test_predict_return_plot(m):
     image = get_data(path="2019_YELL_2_528000_4978000_image_crop2.png")
-    image = np.array(Image.open(image)).astype("float32")
+    image = np.array(Image.open(image))
     plot = m.predict_image(image = image, return_plot=True)
-    assert not isinstance(plot, pd.DataFrame)
+    assert isinstance(plot, np.ndarray)
 
 def test_predict_big_file(m, tmpdir):
     csv_file = big_file()
@@ -254,28 +250,28 @@ def test_override_transforms():
     path, image, target = next(iter(train_ds))
     assert m.transforms.__doc__ == "This is the new transform"
 
-def test_train_empty_batch(m):
-    """If module encounters an invalid batch, print and skip"""
-    class EmptyDataset(Dataset):
-        def __init__(self):
-            pass
-        def __len__(self):
-            return 10
-        def __getitem__(self, idx):
-            return None, None
-    ds = EmptyDataset()
+#def test_train_empty_batch(m):
+    #"""If module encounters an invalid batch, print and skip"""
+    #class EmptyDataset(Dataset):
+        #def __init__(self):
+            #pass
+        #def __len__(self):
+            #return 10
+        #def __getitem__(self, idx):
+            #return None, None
+    #ds = EmptyDataset()
     
-    data_loader = torch.utils.data.DataLoader(
-        ds,
-        batch_size=1,
-        shuffle=False,
-        collate_fn=utilities.collate_fn,
-        num_workers=0
-    )
+    #data_loader = torch.utils.data.DataLoader(
+        #ds,
+        #batch_size=1,
+        #shuffle=False,
+        #collate_fn=utilities.collate_fn,
+        #num_workers=0
+    #)
     
-    for batch in data_loader:
-        image, target = batch
-        assert image[0] is None
-        assert target[0] is None
+    #for batch in data_loader:
+        #image, target = batch
+        #assert image[0] is None
+        #assert target[0] is None
         
-    m.trainer.fit(m, data_loader)
\ No newline at end of file
+    #m.trainer.fit(m, data_loader)
\ No newline at end of file
